Package: likelihood
Version: 1.9
Title: Methods for Maximum Likelihood Estimation
Date: 2023-03-30
Authors@R: c(person("Lora", "Murphy", role = c("aut", "cre"), email="murphyl@caryinstitute.org"))
Author: Lora Murphy [aut, cre]
Maintainer: Lora Murphy <murphyl@caryinstitute.org>
Description: Tools for maximum likelihood estimation of parameters 
  of scientific models. Based on Goffe et al (1994) <doi:10.1016/0304-4076(94)90038-8>.
Depends: R (>= 2.1.1), nlme
License: GPL-2
LazyData: true
NeedsCompilation: no
Packaged: 2023-03-30 14:44:19 UTC; lora
Repository: CRAN
Date/Publication: 2023-03-30 16:50:04 UTC
Built: R 4.6.0; ; 2026-04-27 10:25:18 UTC; unix
